# 0. Folder monitor for new files - watchdog - done
# 0a. Use emitter https://pyee.readthedocs.io/en/latest/api/
# 1. Combine images by number, name and extension
# 2. Create video stream from the images chunks
# 3. Use opencv to preview the realtime stream
# 4. Feed stream to yolo
# 5. Create library lucky robots installable via pip